@@ -456,12 +456,26 @@ class _1D_RawDataMixin():
             fid = fid.reshape(int(self["td"]/2), 2)          # type: ignore # mixin
             fid = np.transpose(fid)
             self._fid = fid[0] + (1j * fid[1])
+        else:
+            raise ValueError(f"Unknown dtypa value '{self['dtypa']}'.")
 
-    def raw_data(self) -> np.ndarray:
+    def raw_data(self,
+                 shift_grpdly: bool = False
+                 ) -> np.ndarray:
         """
         Returns the FID as a complex |ndarray|.
+
+        Parameters
+        ----------
+        shift_grpdly : bool, default False
+            Whether to circularly shift the group delay to the end of the FID,
+            i.e. take the first N points (where N is given by the TopSpin
+            GRPDLY parameter) and move them to the end of the FID.
         """
-        return self.fid
+        if shift_grpdly:
+            return np.roll(self.fid, -int(self["GRPDLY"]))
+        else:
+            return self.fid
 
 
 class _1D_ProcDataMixin():
@@ -538,29 +552,40 @@ class _1D_ProcDataMixin():
 
     def proc_data(self,
                   bounds: TBounds = "",
+                  component: str = "real",
                   ) -> np.ndarray:
-        """Returns the real part of the spectrum as a real-valued |ndarray|.
+        """Returns the processed spectrum as a real-valued |ndarray|. By
+        default this returns the real part of the spectrum, but this can be
+        changed using the `component` argument.
 
         Note that if (for example) a magnitude mode calculation has been
         performed, then the "real" part is actually the magnitude mode
         spectrum. In short, the "real" part is whatever is stored in the ``1r``
         file.
 
-        This is used in constructing the *y*-values to be plotted.
-
         Parameters
         ----------
         bounds : str or (float, float), optional
             Bounds can be specified as a string ``lower..upper`` or a tuple of
             floats ``(lower, upper)``, upon which the appropriate slice of the
             spectrum will be taken.
+        component : str from {"real", "r", "imag", "i"} (default "real")
+            The component of the processed data to return. `"real"` or `"r"`
+            return the real part of the spectrum, the others return the
+            imaginary part.
 
         Returns
         -------
         ndarray
-            The real spectrum or the slice of interest.
+            The spectrum or the slice of interest.
         """
-        return self.real[self.bounds_to_slice(bounds)]
+        if component in ['real', 'r']:
+            return self.real[self.bounds_to_slice(bounds)]
+        elif component in ['imag', 'i']:
+            return self.imag[self.bounds_to_slice(bounds)]
+        else:
+            raise ValueError(f"Invalid value '{component}' for 'component'"
+                             " argument.")
 
     def integrate(self,
                   peak: OF = None,
@@ -692,16 +717,22 @@ class _2D_RawDataMixin():
         if self["dtypa"] == 0:                             # type: ignore # mixin
             dtype = "<" if self["bytorda"] == 0 else ">"   # type: ignore # mixin
             dtype += "i4"
+            blocksize = 256
+        elif self["dtypa"] == 2:
+            dtype = "<" if self["bytorda"] == 0 else ">"  # type: ignore # mixin
+            dtype += "d"
+            blocksize = 128
         else:
-            raise NotImplementedError("float data not yet accepted")
+            raise ValueError(f"Unknown dtypa value '{self['dtypa']}'.")
         # Read in the data from the ser file.
         ser = np.fromfile(self._p_ser, dtype=dtype)
         # Reshape the matrix according to TD. Note that in the ser file, each
-        # new FID always begins at a new block of 256 data points. Effectively,
-        # this means that TD2 is rounded up to the nearest multiple of 256.
+        # new FID always begins at a new block of 256/128 data points (256 for
+        # int, 128 for double). Effectively, this means that TD2 is rounded up
+        # to the nearest multiple of 256/128.
         td1, td2 = self["td"]   # type: ignore # mixin
-        if td2 % 256 != 0:
-            td2_eff = math.ceil(td2 / 256) * 256
+        if td2 % blocksize != 0:
+            td2_eff = math.ceil(td2 / blocksize) * blocksize
             ser = ser.reshape((td1, td2_eff))
             ser = ser[:, :td2]
         else:
@@ -713,8 +744,23 @@ class _2D_RawDataMixin():
         ser[:,:,1] = ser[:,:,1] * 1j
         self._ser = ser.sum(axis=2) * (2 ** self["nc"])  # type: ignore # mixin
 
-    def raw_data(self):
-        return self.ser
+    def raw_data(self,
+                 shift_grpdly: bool = False
+                 ) -> np.ndarray:
+        """
+        Returns the 2D raw data matrix as a 2D complex-valued |ndarray|.
+
+        Parameters
+        ----------
+        shift_grpdly : bool, default False
+            Whether to circularly shift the group delay to the end of each FID,
+            i.e. take the first N points (where N is given by the TopSpin
+            GRPDLY parameter) and move them to the end of each FID.
+        """
+        if shift_grpdly:
+            return np.roll(self.ser, -int(self["GRPDLY"]), axis=1)
+        else:
+            return self.ser
 
 
 class _2D_ProcDataMixin():
@@ -822,11 +868,11 @@ class _2D_ProcDataMixin():
     def proc_data(self,
                   f1_bounds: TBounds = "",
                   f2_bounds: TBounds = "",
+                  component: str = "rr",
                   ) -> np.ndarray:
-        """Returns the real part of the spectrum (the 'RR quadrant') as a
-        two-dimensional, real-valued |ndarray|.
-
-        This is used in constructing the *z*-values to be plotted.
+        """Returns the processed 2D data as a two-dimensional, real-valued
+        |ndarray|. By default this returns the real part of the spectrum (the
+        'RR quadrant'), but this can be changed using the `component` argument.
 
         Note that if a magnitude mode calculation has been performed, this will
         return the magnitude mode spectrum (i.e. it returns whatever is in
@@ -838,15 +884,28 @@ class _2D_ProcDataMixin():
             Bounds for the indirect dimension.
         f2_bounds : str or (float, float), optional
             Bounds for the direct dimension.
+        component : str from {"rr", "ri", "ir", "ii"} (default "ii")
+            The quadrant of the processed data to return.
 
         Returns
         -------
         ndarray
-            The doubly real spectrum, or the section of interest.
+            The processed 2D data, or the section of interest.
         """
+        if component == 'rr':
+            data = self.rr
+        elif component == 'ri':
+            data = self.ri
+        elif component == 'ir':
+            data = self.ir
+        elif component == 'ii':
+            data = self.ii
+        else:
+            raise ValueError(f"Invalid value '{component}' for 'component'"
+                             " argument.")
         f1_slice = self.bounds_to_slice(axis=0, bounds=f1_bounds)
         f2_slice = self.bounds_to_slice(axis=1, bounds=f2_bounds)
-        return self.rr[f1_slice, f2_slice]
+        return data[f1_slice, f2_slice]
 
     def integrate(self,
                   peak: Optional[Tuple[float, float]] = None,
